@@ -1,4 +1,3 @@
-#' @importFrom sjmisc var_rename remove_empty_cols
 #' @importFrom stats confint na.omit
 #' @importFrom sjlabelled get_labels as_numeric
 #' @importFrom insight find_response get_data model_info
@@ -14,13 +13,27 @@ ggemmeans <- function(model,
                       ...) {
 
   if (!requireNamespace("emmeans")) {
-    stop("Package `emmeans` required to compute marginal effects for clmm-models.", call. = FALSE)
+    stop("Package `emmeans` required to compute marginal effects with `ggemmeans()`.", call. = FALSE)
   }
 
   # check arguments
-  type <- match.arg(type, choices = c("fe", "fe.zi", "re", "re.zi"))
+  type <- match.arg(type, choices = c("fe", "fixed", "count", "re", "random", "fe.zi", "zero_inflated", "re.zi", "zero_inflated_random"))
   model_name <- deparse(substitute(model))
 
+  type <- switch(
+    type,
+    "fixed" = ,
+    "count" = "fe",
+    "random" = "re",
+    "zi" = ,
+    "zero_inflated" = "fe.zi",
+    "zi_random" = ,
+    "zero_inflated_random" = "re.zi",
+    "survival" = "surv",
+    "cumulative_hazard" = "cumhaz"    ,
+    type
+  )
+
   # check if terms are a formula
   if (!missing(terms) && !is.null(terms) && inherits(terms, "formula")) {
     terms <- all.vars(terms)
@@ -92,7 +105,7 @@ ggemmeans <- function(model,
 
   attr(prediction_data, "continuous.group") <- attr(data_grid, "continuous.group")
 
-  if (model_info$is_ordinal | model_info$is_categorical) {
+  if (model_info$is_ordinal || model_info$is_categorical || model_info$is_multinomial) {
     colnames(prediction_data)[1] <- "response.level"
   }
 
@@ -150,7 +163,7 @@ ggemmeans <- function(model,
     "fixed-effects"
   else if (inherits(model, "gls"))
     "satterthwaite"
-  else if (model_info$is_ordinal | model_info$is_categorical)
+  else if (model_info$is_ordinal || model_info$is_categorical || model_info$is_multinomial)
     "prob"
   else if (model_info$is_zero_inflated && type %in% c("fe", "re") && inherits(model, "glmmTMB"))
     "link"
