@@ -1,12 +1,14 @@
-#' @title Get marginal effects from model terms
+#' @title Marginal effects and estimated marginal means from regression models
 #' @name ggpredict
 #'
 #' @description
-#'   \code{ggpredict()} computes estimated marginal means (predicted values) for the
-#'   response, at the margin of specific values from certain model terms.
-#'   \code{ggeffect()} computes marginal effects by internally calling
-#'   \code{\link[effects]{Effect}}, while \code{ggemmeans()} computes marginal
-#'   effects by internally calling \code{\link[emmeans]{emmeans}}.
+#'   The \pkg{ggeffects} package computes estimated marginal means (predicted values) for the
+#'   response, at the margin of specific values or levels from certain model terms,
+#'   i.e. it generates predictions by a model by holding the non-focal variables
+#'   constant and varying the focal variable(s). \cr \cr
+#'   \code{ggpredict()} uses \code{predict()} for generating predictions,
+#'   while \code{ggeffect()} computes marginal effects by internally calling
+#'   \code{\link[effects]{Effect}} and \code{ggemmeans()} uses \code{\link[emmeans]{emmeans}}.
 #'   The result is returned as consistent data frame.
 #'
 #' @param model A fitted model object, or a list of model objects. Any model
@@ -38,7 +40,7 @@
 #'   \pkg{GLMMadaptive} with zero-inflation component \emph{always} condition on
 #'   the zero-inflation part of the model (see 'Details').
 #'   \describe{
-#'     \item{\code{"fe"}}{
+#'     \item{\code{"fe"} (or \code{"fixed"} or \code{"count"})}{
 #'     Predicted values are conditioned on the fixed effects or conditional
 #'     model only (for mixed models: predicted values are on the population-level
 #'     and \emph{confidence intervals} are returned). For instance, for models
@@ -48,7 +50,7 @@
 #'     \code{predict(..., type = "link")} (however, predicted values are
 #'     back-transformed to the response scale).
 #'     }
-#'     \item{\code{"re"}}{
+#'     \item{\code{"re"} (or \code{"random"})}{
 #'     This only applies to mixed models, and \code{type = "re"} does not
 #'     condition on the zero-inflation component of the model. \code{type = "re"}
 #'     still returns population-level predictions, however, unlike \code{type = "fe"},
@@ -63,7 +65,7 @@
 #'     name of the related random effect term to the \code{terms}-argument
 #'     (for more details, see \href{https://strengejacke.github.io/ggeffects/articles/introduction_effectsatvalues.html}{this vignette}).
 #'     }
-#'     \item{\code{"fe.zi"}}{
+#'     \item{\code{"fe.zi"} (or \code{"zero_inflated"} or \code{"zi"})}{
 #'     Predicted values are conditioned on the fixed effects and the zero-inflation
 #'     component. For instance, for models fitted with \code{zeroinfl}
 #'     from \pkg{pscl}, this would return the predicted response (\code{mu*(1-p)})
@@ -73,7 +75,7 @@
 #'     zero-inflation component, this type calls \code{predict(..., type = "response")}.
 #'     See 'Details'.
 #'     }
-#'     \item{\code{"re.zi"}}{
+#'     \item{\code{"re.zi"} (or \code{"zi_random"} or \code{"zero_inflated_random"})}{
 #'     Predicted values are conditioned on the zero-inflation component and
 #'     take the random effects uncertainty into account. For models fitted with
 #'     \code{glmmTMB()}, \code{hurdle()} or \code{zeroinfl()}, this would return the
@@ -88,7 +90,7 @@
 #'     random effects variances. Currently supported models are \code{glmmTMB}
 #'     and \code{merMod}. See \code{...} for details on number of simulations.
 #'     }
-#'     \item{\code{"surv"} and \code{"cumhaz"}}{
+#'     \item{\code{"surv"} and \code{"cumhaz"} (or \code{"survival"} and \code{"cumulative_hazard"})}{
 #'     Applies only to \code{coxph}-objects from the \pkg{survial}-package and
 #'     calculates the survival probability or the cumulative hazard of an event.
 #'     }
@@ -97,7 +99,7 @@
 #'   covariates over which the effect is "averaged". The default is "mean".
 #'   See \code{\link[sjmisc]{typical_value}} for options.
 #' @param back.transform Logical, if \code{TRUE} (the default), predicted values
-#'   for log- or log-log transformend responses will be back-transformed to
+#'   for log- or log-log transformed responses will be back-transformed to
 #'   original response-scale.
 #' @param ppd Logical, if \code{TRUE}, predictions for Stan-models are
 #'   based on the posterior predictive distribution
@@ -118,15 +120,16 @@
 #'   (and \code{interval = "confidence"} is equivalent to \code{type = "fe"}).
 #'   Note that prediction intervals are not available for all models.
 #' @param vcov.fun String, indicating the name of the \code{vcov*()}-function
-#'    from the \pkg{sandwich}-package, e.g. \code{vcov.fun = "vcovCL"},
-#'    which is used to compute robust standard errors for predictions.
-#'    If \code{NULL}, standard errors (and confidence intervals) for predictions
-#'    are based on the standard errors as returned by the \code{predict()}-function.
-#'    \strong{Note} that probably not all model objects that work with \code{ggpredict()}
-#'    are also supported by the \pkg{sandwich}-package.
+#'    from the \pkg{sandwich} or \pkg{clubSandwich}-package, e.g.
+#'    \code{vcov.fun = "vcovCL"}, which is used to compute (cluster) robust
+#'    standard errors for predictions. If \code{NULL}, standard errors (and
+#'    confidence intervals) for predictions are based on the standard errors as
+#'    returned by the \code{predict()}-function. \strong{Note} that probably not
+#'    all model objects that work with \code{ggpredict()} are also supported
+#'    by the \pkg{sandwich} or \pkg{clubSandwich}-package.
 #' @param vcov.type Character vector, specifying the estimation type for the
 #'    robust covariance matrix estimation (see \code{\link[sandwich]{vcovHC}}
-#'    for details).
+#'    or \code{\link[clubSandwich]{vcovCR}} for details).
 #' @param vcov.args List of named vectors, used as additional arguments that
 #'    are passed down to \code{vcov.fun}.
 #' @param ... For \code{ggpredict()}, further arguments passed down to
@@ -402,7 +405,6 @@
 #' ggeffect(fit, terms = "e17age")
 #'
 #' @importFrom stats predict predict.glm na.omit
-#' @importFrom sjmisc remove_empty_cols
 #' @importFrom insight find_random find_predictors model_info find_formula
 #' @export
 ggpredict <- function(model,
@@ -419,10 +421,24 @@ ggpredict <- function(model,
                       interval = "confidence",
                       ...) {
   # check arguments
-  type <- match.arg(type, choices = c("fe", "re", "fe.zi", "re.zi", "sim", "surv", "cumhaz", "debug"))
+  type <- match.arg(type, choices = c("fe", "fixed", "count", "re", "random", "fe.zi", "zero_inflated", "re.zi", "zero_inflated_random", "sim", "surv", "survival", "cumhaz", "cumulative_hazard", "debug"))
   interval <- match.arg(interval, choices = c("confidence", "prediction"))
   model.name <- deparse(substitute(model))
 
+  type <- switch(
+    type,
+    "fixed" = ,
+    "count" = "fe",
+    "random" = "re",
+    "zi" = ,
+    "zero_inflated" = "fe.zi",
+    "zi_random" = ,
+    "zero_inflated_random" = "re.zi",
+    "survival" = "surv",
+    "cumulative_hazard" = "cumhaz"    ,
+    type
+  )
+
   # check if terms are a formula
   if (!missing(terms) && !is.null(terms) && inherits(terms, "formula")) {
     terms <- all.vars(terms)
@@ -432,7 +448,7 @@ ggpredict <- function(model,
   # extract just the mer-part then
   if (is.gamm(model) || is.gamm4(model)) model <- model$gam
 
-  if (inherits(model, "list") && !inherits(model, "bamlss")) {
+  if (inherits(model, "list") && !inherits(model, c("bamlss", "maxLik"))) {
     res <- lapply(model, function(.x) {
       ggpredict_helper(
         model = .x,
